@@ -1,7 +1,7 @@
 """Service-Status for Object-API."""
 from __future__ import annotations
 
-from . import base, dictionary
+from . import base
 
 import logging
 
